"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2017 The Ray Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import abc
import collections.abc
import grpc
import grpc.aio
import model.ray.serve_pb2
import typing

_T = typing.TypeVar('_T')

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta):
    ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore
    ...

class RayServeAPIServiceStub:
    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    ListApplications: grpc.UnaryUnaryMultiCallable[
        model.ray.serve_pb2.ListApplicationsRequest,
        model.ray.serve_pb2.ListApplicationsResponse,
    ]
    Healthz: grpc.UnaryUnaryMultiCallable[
        model.ray.serve_pb2.HealthzRequest,
        model.ray.serve_pb2.HealthzResponse,
    ]

class RayServeAPIServiceAsyncStub:
    ListApplications: grpc.aio.UnaryUnaryMultiCallable[
        model.ray.serve_pb2.ListApplicationsRequest,
        model.ray.serve_pb2.ListApplicationsResponse,
    ]
    Healthz: grpc.aio.UnaryUnaryMultiCallable[
        model.ray.serve_pb2.HealthzRequest,
        model.ray.serve_pb2.HealthzResponse,
    ]

class RayServeAPIServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ListApplications(
        self,
        request: model.ray.serve_pb2.ListApplicationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.ray.serve_pb2.ListApplicationsResponse, collections.abc.Awaitable[model.ray.serve_pb2.ListApplicationsResponse]]: ...
    @abc.abstractmethod
    def Healthz(
        self,
        request: model.ray.serve_pb2.HealthzRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.ray.serve_pb2.HealthzResponse, collections.abc.Awaitable[model.ray.serve_pb2.HealthzResponse]]: ...

def add_RayServeAPIServiceServicer_to_server(servicer: RayServeAPIServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...

class UserDefinedServiceStub:
    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    __call__: grpc.UnaryUnaryMultiCallable[
        model.ray.serve_pb2.UserDefinedMessage,
        model.ray.serve_pb2.UserDefinedResponse,
    ]
    Method1: grpc.UnaryUnaryMultiCallable[
        model.ray.serve_pb2.UserDefinedMessage,
        model.ray.serve_pb2.UserDefinedResponse,
    ]
    Method2: grpc.UnaryUnaryMultiCallable[
        model.ray.serve_pb2.UserDefinedMessage2,
        model.ray.serve_pb2.UserDefinedResponse2,
    ]
    Streaming: grpc.UnaryStreamMultiCallable[
        model.ray.serve_pb2.UserDefinedMessage,
        model.ray.serve_pb2.UserDefinedResponse,
    ]

class UserDefinedServiceAsyncStub:
    __call__: grpc.aio.UnaryUnaryMultiCallable[
        model.ray.serve_pb2.UserDefinedMessage,
        model.ray.serve_pb2.UserDefinedResponse,
    ]
    Method1: grpc.aio.UnaryUnaryMultiCallable[
        model.ray.serve_pb2.UserDefinedMessage,
        model.ray.serve_pb2.UserDefinedResponse,
    ]
    Method2: grpc.aio.UnaryUnaryMultiCallable[
        model.ray.serve_pb2.UserDefinedMessage2,
        model.ray.serve_pb2.UserDefinedResponse2,
    ]
    Streaming: grpc.aio.UnaryStreamMultiCallable[
        model.ray.serve_pb2.UserDefinedMessage,
        model.ray.serve_pb2.UserDefinedResponse,
    ]

class UserDefinedServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def __call__(
        self,
        request: model.ray.serve_pb2.UserDefinedMessage,
        context: _ServicerContext,
    ) -> typing.Union[model.ray.serve_pb2.UserDefinedResponse, collections.abc.Awaitable[model.ray.serve_pb2.UserDefinedResponse]]: ...
    @abc.abstractmethod
    def Method1(
        self,
        request: model.ray.serve_pb2.UserDefinedMessage,
        context: _ServicerContext,
    ) -> typing.Union[model.ray.serve_pb2.UserDefinedResponse, collections.abc.Awaitable[model.ray.serve_pb2.UserDefinedResponse]]: ...
    @abc.abstractmethod
    def Method2(
        self,
        request: model.ray.serve_pb2.UserDefinedMessage2,
        context: _ServicerContext,
    ) -> typing.Union[model.ray.serve_pb2.UserDefinedResponse2, collections.abc.Awaitable[model.ray.serve_pb2.UserDefinedResponse2]]: ...
    @abc.abstractmethod
    def Streaming(
        self,
        request: model.ray.serve_pb2.UserDefinedMessage,
        context: _ServicerContext,
    ) -> typing.Union[collections.abc.Iterator[model.ray.serve_pb2.UserDefinedResponse], collections.abc.AsyncIterator[model.ray.serve_pb2.UserDefinedResponse]]: ...

def add_UserDefinedServiceServicer_to_server(servicer: UserDefinedServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...

class FruitServiceStub:
    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    FruitStand: grpc.UnaryUnaryMultiCallable[
        model.ray.serve_pb2.FruitAmounts,
        model.ray.serve_pb2.FruitCosts,
    ]

class FruitServiceAsyncStub:
    FruitStand: grpc.aio.UnaryUnaryMultiCallable[
        model.ray.serve_pb2.FruitAmounts,
        model.ray.serve_pb2.FruitCosts,
    ]

class FruitServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def FruitStand(
        self,
        request: model.ray.serve_pb2.FruitAmounts,
        context: _ServicerContext,
    ) -> typing.Union[model.ray.serve_pb2.FruitCosts, collections.abc.Awaitable[model.ray.serve_pb2.FruitCosts]]: ...

def add_FruitServiceServicer_to_server(servicer: FruitServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...

class RayServeBenchmarkServiceStub:
    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    grpc_call: grpc.UnaryUnaryMultiCallable[
        model.ray.serve_pb2.ArrayData,
        model.ray.serve_pb2.ModelOutput,
    ]
    call_with_string: grpc.UnaryUnaryMultiCallable[
        model.ray.serve_pb2.StringData,
        model.ray.serve_pb2.ModelOutput,
    ]

class RayServeBenchmarkServiceAsyncStub:
    grpc_call: grpc.aio.UnaryUnaryMultiCallable[
        model.ray.serve_pb2.ArrayData,
        model.ray.serve_pb2.ModelOutput,
    ]
    call_with_string: grpc.aio.UnaryUnaryMultiCallable[
        model.ray.serve_pb2.StringData,
        model.ray.serve_pb2.ModelOutput,
    ]

class RayServeBenchmarkServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def grpc_call(
        self,
        request: model.ray.serve_pb2.ArrayData,
        context: _ServicerContext,
    ) -> typing.Union[model.ray.serve_pb2.ModelOutput, collections.abc.Awaitable[model.ray.serve_pb2.ModelOutput]]: ...
    @abc.abstractmethod
    def call_with_string(
        self,
        request: model.ray.serve_pb2.StringData,
        context: _ServicerContext,
    ) -> typing.Union[model.ray.serve_pb2.ModelOutput, collections.abc.Awaitable[model.ray.serve_pb2.ModelOutput]]: ...

def add_RayServeBenchmarkServiceServicer_to_server(servicer: RayServeBenchmarkServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from agent.agent.v1alpha import agent_pb2 as agent_dot_agent_dot_v1alpha_dot_agent__pb2
from agent.agent.v1alpha import chat_pb2 as agent_dot_agent_dot_v1alpha_dot_chat__pb2
from agent.agent.v1alpha import table_pb2 as agent_dot_agent_dot_v1alpha_dot_table__pb2


class AgentPublicServiceStub(object):
    """AgentPublicService exposes the public endpoints that allow clients to
    manage agents.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Liveness = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/Liveness',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_agent__pb2.LivenessRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_agent__pb2.LivenessResponse.FromString,
                )
        self.Readiness = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/Readiness',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_agent__pb2.ReadinessRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_agent__pb2.ReadinessResponse.FromString,
                )
        self.CreateChat = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/CreateChat',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.CreateChatRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.CreateChatResponse.FromString,
                )
        self.ListChats = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/ListChats',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.ListChatsRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.ListChatsResponse.FromString,
                )
        self.UpdateChat = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/UpdateChat',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.UpdateChatRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.UpdateChatResponse.FromString,
                )
        self.GetChat = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/GetChat',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.GetChatRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.GetChatResponse.FromString,
                )
        self.DeleteChat = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/DeleteChat',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.DeleteChatRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.DeleteChatResponse.FromString,
                )
        self.ListMessages = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/ListMessages',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.ListMessagesRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.ListMessagesResponse.FromString,
                )
        self.ChatWithAgent = channel.unary_stream(
                '/agent.agent.v1alpha.AgentPublicService/ChatWithAgent',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.ChatWithAgentRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.ChatWithAgentResponse.FromString,
                )
        self.BindChatTable = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/BindChatTable',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.BindChatTableRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.BindChatTableResponse.FromString,
                )
        self.UnbindChatTable = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/UnbindChatTable',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UnbindChatTableRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UnbindChatTableResponse.FromString,
                )
        self.ListChatTables = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/ListChatTables',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.ListChatTablesRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.ListChatTablesResponse.FromString,
                )
        self.ListTables = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/ListTables',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.ListTablesRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.ListTablesResponse.FromString,
                )
        self.CreateTable = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/CreateTable',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.CreateTableRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.CreateTableResponse.FromString,
                )
        self.GetTable = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/GetTable',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.GetTableRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.GetTableResponse.FromString,
                )
        self.UpdateTable = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/UpdateTable',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateTableRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateTableResponse.FromString,
                )
        self.DeleteTable = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/DeleteTable',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.DeleteTableRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.DeleteTableResponse.FromString,
                )
        self.ChatWithTableBuilderAgent = channel.unary_stream(
                '/agent.agent.v1alpha.AgentPublicService/ChatWithTableBuilderAgent',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.ChatWithTableBuilderAgentRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.ChatWithTableBuilderAgentResponse.FromString,
                )
        self.ListTableBuilderAgentMessages = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/ListTableBuilderAgentMessages',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.ListTableBuilderAgentMessagesRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.ListTableBuilderAgentMessagesResponse.FromString,
                )
        self.GetColumnDefinitions = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/GetColumnDefinitions',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.GetColumnDefinitionsRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.GetColumnDefinitionsResponse.FromString,
                )
        self.UpdateColumnDefinitions = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/UpdateColumnDefinitions',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateColumnDefinitionsRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateColumnDefinitionsResponse.FromString,
                )
        self.GetColumnDefinition = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/GetColumnDefinition',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.GetColumnDefinitionRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.GetColumnDefinitionResponse.FromString,
                )
        self.RecomputeColumn = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/RecomputeColumn',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.RecomputeColumnRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.RecomputeColumnResponse.FromString,
                )
        self.ListRows = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/ListRows',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.ListRowsRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.ListRowsResponse.FromString,
                )
        self.GetRow = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/GetRow',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.GetRowRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.GetRowResponse.FromString,
                )
        self.InsertRow = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/InsertRow',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.InsertRowRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.InsertRowResponse.FromString,
                )
        self.UpdateRow = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/UpdateRow',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateRowRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateRowResponse.FromString,
                )
        self.UpdateRows = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/UpdateRows',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateRowsRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateRowsResponse.FromString,
                )
        self.DeleteRow = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/DeleteRow',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.DeleteRowRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.DeleteRowResponse.FromString,
                )
        self.DeleteRows = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/DeleteRows',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.DeleteRowsRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.DeleteRowsResponse.FromString,
                )
        self.MoveRows = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/MoveRows',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.MoveRowsRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.MoveRowsResponse.FromString,
                )
        self.GetCell = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/GetCell',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.GetCellRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.GetCellResponse.FromString,
                )
        self.UpdateCell = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/UpdateCell',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateCellRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateCellResponse.FromString,
                )
        self.ResetCell = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/ResetCell',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.ResetCellRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.ResetCellResponse.FromString,
                )
        self.RecomputeCell = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/RecomputeCell',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.RecomputeCellRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.RecomputeCellResponse.FromString,
                )
        self.LockCell = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/LockCell',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.LockCellRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.LockCellResponse.FromString,
                )
        self.UnlockCell = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/UnlockCell',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UnlockCellRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UnlockCellResponse.FromString,
                )
        self.GetTableEvents = channel.unary_stream(
                '/agent.agent.v1alpha.AgentPublicService/GetTableEvents',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.GetTableEventsRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.GetTableEventsResponse.FromString,
                )
        self.ExportTable = channel.unary_unary(
                '/agent.agent.v1alpha.AgentPublicService/ExportTable',
                request_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.ExportTableRequest.SerializeToString,
                response_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.ExportTableResponse.FromString,
                )


class AgentPublicServiceServicer(object):
    """AgentPublicService exposes the public endpoints that allow clients to
    manage agents.
    """

    def Liveness(self, request, context):
        """Check if the agent server is alive

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Readiness(self, request, context):
        """Check if the agent server is ready

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateChat(self, request, context):
        """Create a chat

        Creates a chat.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListChats(self, request, context):
        """List chats

        Returns a list of chats.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateChat(self, request, context):
        """Update a chat

        Updates a chat.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetChat(self, request, context):
        """Get a chat

        Gets a chat.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteChat(self, request, context):
        """Delete a chat

        Deletes a chat.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListMessages(self, request, context):
        """List messages

        Returns a paginated list of messages.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChatWithAgent(self, request, context):
        """Chat with agent

        Chat with the agent.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BindChatTable(self, request, context):
        """Bind table to chat

        Binds a table to a chat.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnbindChatTable(self, request, context):
        """Unbind table from chat

        Unbinds a table from a chat.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListChatTables(self, request, context):
        """List chat tables

        Returns a list of tables bound to a chat.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListTables(self, request, context):
        """List tables

        Returns a paginated list of tables.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateTable(self, request, context):
        """Create a table

        Creates a table.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTable(self, request, context):
        """Get table

        Gets a table.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTable(self, request, context):
        """Update table

        Updates a table.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteTable(self, request, context):
        """Delete table

        Deletes a table.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChatWithTableBuilderAgent(self, request, context):
        """Chat with table builder agent

        Chat with the table builder agent.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListTableBuilderAgentMessages(self, request, context):
        """List table builder agent messages

        Lists the messages from the table builder agent.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetColumnDefinitions(self, request, context):
        """Get column definitions

        Gets column definitions for a table.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateColumnDefinitions(self, request, context):
        """Update column definitions

        Updates column definitions for a table. When updating the column
        definitions, if the column's agent instructions are updated, the existing
        cells in that column will be cleared and recomputed. This ensures that all
        data reflects the latest instructions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetColumnDefinition(self, request, context):
        """Get column definition

        Gets a column definition for a table.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RecomputeColumn(self, request, context):
        """Recompute column

        Recomputes all the cells in a column.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRows(self, request, context):
        """List rows

        Returns list of rows.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRow(self, request, context):
        """Get row

        Gets a row from a table.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InsertRow(self, request, context):
        """Insert row

        Inserts a row into a table.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateRow(self, request, context):
        """Update row

        Updates a row in a table.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateRows(self, request, context):
        """Update rows

        Updates multiple rows in a table.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteRow(self, request, context):
        """Delete row

        Deletes a row from a table.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteRows(self, request, context):
        """Delete rows

        Deletes multiple rows from a table.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MoveRows(self, request, context):
        """Move row

        Moves a row to a new position in a table.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCell(self, request, context):
        """Get cell

        Gets a cell from a table.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateCell(self, request, context):
        """Update cell

        Updates a cell in a table.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetCell(self, request, context):
        """Reset cell

        Resets a cell in a table. Resetting a cell clears its user input and
        reverts to using the computed value if available. This operation only
        affects cells that have a user input set.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RecomputeCell(self, request, context):
        """Recompute cell

        Recomputes a cell in a table.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LockCell(self, request, context):
        """Lock cell

        Locks a cell in a table.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnlockCell(self, request, context):
        """Unlock cell

        Unlocks a cell in a table.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTableEvents(self, request, context):
        """Get table events

        Returns a list of events for a table.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExportTable(self, request, context):
        """Export table

        Exports table data.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AgentPublicServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Liveness': grpc.unary_unary_rpc_method_handler(
                    servicer.Liveness,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_agent__pb2.LivenessRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_agent__pb2.LivenessResponse.SerializeToString,
            ),
            'Readiness': grpc.unary_unary_rpc_method_handler(
                    servicer.Readiness,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_agent__pb2.ReadinessRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_agent__pb2.ReadinessResponse.SerializeToString,
            ),
            'CreateChat': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateChat,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.CreateChatRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.CreateChatResponse.SerializeToString,
            ),
            'ListChats': grpc.unary_unary_rpc_method_handler(
                    servicer.ListChats,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.ListChatsRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.ListChatsResponse.SerializeToString,
            ),
            'UpdateChat': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateChat,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.UpdateChatRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.UpdateChatResponse.SerializeToString,
            ),
            'GetChat': grpc.unary_unary_rpc_method_handler(
                    servicer.GetChat,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.GetChatRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.GetChatResponse.SerializeToString,
            ),
            'DeleteChat': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteChat,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.DeleteChatRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.DeleteChatResponse.SerializeToString,
            ),
            'ListMessages': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMessages,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.ListMessagesRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.ListMessagesResponse.SerializeToString,
            ),
            'ChatWithAgent': grpc.unary_stream_rpc_method_handler(
                    servicer.ChatWithAgent,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.ChatWithAgentRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.ChatWithAgentResponse.SerializeToString,
            ),
            'BindChatTable': grpc.unary_unary_rpc_method_handler(
                    servicer.BindChatTable,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.BindChatTableRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.BindChatTableResponse.SerializeToString,
            ),
            'UnbindChatTable': grpc.unary_unary_rpc_method_handler(
                    servicer.UnbindChatTable,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UnbindChatTableRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UnbindChatTableResponse.SerializeToString,
            ),
            'ListChatTables': grpc.unary_unary_rpc_method_handler(
                    servicer.ListChatTables,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.ListChatTablesRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.ListChatTablesResponse.SerializeToString,
            ),
            'ListTables': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTables,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.ListTablesRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.ListTablesResponse.SerializeToString,
            ),
            'CreateTable': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTable,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.CreateTableRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.CreateTableResponse.SerializeToString,
            ),
            'GetTable': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTable,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.GetTableRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.GetTableResponse.SerializeToString,
            ),
            'UpdateTable': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateTable,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateTableRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateTableResponse.SerializeToString,
            ),
            'DeleteTable': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteTable,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.DeleteTableRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.DeleteTableResponse.SerializeToString,
            ),
            'ChatWithTableBuilderAgent': grpc.unary_stream_rpc_method_handler(
                    servicer.ChatWithTableBuilderAgent,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.ChatWithTableBuilderAgentRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.ChatWithTableBuilderAgentResponse.SerializeToString,
            ),
            'ListTableBuilderAgentMessages': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTableBuilderAgentMessages,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.ListTableBuilderAgentMessagesRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_chat__pb2.ListTableBuilderAgentMessagesResponse.SerializeToString,
            ),
            'GetColumnDefinitions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetColumnDefinitions,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.GetColumnDefinitionsRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.GetColumnDefinitionsResponse.SerializeToString,
            ),
            'UpdateColumnDefinitions': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateColumnDefinitions,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateColumnDefinitionsRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateColumnDefinitionsResponse.SerializeToString,
            ),
            'GetColumnDefinition': grpc.unary_unary_rpc_method_handler(
                    servicer.GetColumnDefinition,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.GetColumnDefinitionRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.GetColumnDefinitionResponse.SerializeToString,
            ),
            'RecomputeColumn': grpc.unary_unary_rpc_method_handler(
                    servicer.RecomputeColumn,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.RecomputeColumnRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.RecomputeColumnResponse.SerializeToString,
            ),
            'ListRows': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRows,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.ListRowsRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.ListRowsResponse.SerializeToString,
            ),
            'GetRow': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRow,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.GetRowRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.GetRowResponse.SerializeToString,
            ),
            'InsertRow': grpc.unary_unary_rpc_method_handler(
                    servicer.InsertRow,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.InsertRowRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.InsertRowResponse.SerializeToString,
            ),
            'UpdateRow': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateRow,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateRowRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateRowResponse.SerializeToString,
            ),
            'UpdateRows': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateRows,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateRowsRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateRowsResponse.SerializeToString,
            ),
            'DeleteRow': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteRow,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.DeleteRowRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.DeleteRowResponse.SerializeToString,
            ),
            'DeleteRows': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteRows,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.DeleteRowsRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.DeleteRowsResponse.SerializeToString,
            ),
            'MoveRows': grpc.unary_unary_rpc_method_handler(
                    servicer.MoveRows,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.MoveRowsRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.MoveRowsResponse.SerializeToString,
            ),
            'GetCell': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCell,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.GetCellRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.GetCellResponse.SerializeToString,
            ),
            'UpdateCell': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateCell,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateCellRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateCellResponse.SerializeToString,
            ),
            'ResetCell': grpc.unary_unary_rpc_method_handler(
                    servicer.ResetCell,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.ResetCellRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.ResetCellResponse.SerializeToString,
            ),
            'RecomputeCell': grpc.unary_unary_rpc_method_handler(
                    servicer.RecomputeCell,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.RecomputeCellRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.RecomputeCellResponse.SerializeToString,
            ),
            'LockCell': grpc.unary_unary_rpc_method_handler(
                    servicer.LockCell,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.LockCellRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.LockCellResponse.SerializeToString,
            ),
            'UnlockCell': grpc.unary_unary_rpc_method_handler(
                    servicer.UnlockCell,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UnlockCellRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.UnlockCellResponse.SerializeToString,
            ),
            'GetTableEvents': grpc.unary_stream_rpc_method_handler(
                    servicer.GetTableEvents,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.GetTableEventsRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.GetTableEventsResponse.SerializeToString,
            ),
            'ExportTable': grpc.unary_unary_rpc_method_handler(
                    servicer.ExportTable,
                    request_deserializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.ExportTableRequest.FromString,
                    response_serializer=agent_dot_agent_dot_v1alpha_dot_table__pb2.ExportTableResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'agent.agent.v1alpha.AgentPublicService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AgentPublicService(object):
    """AgentPublicService exposes the public endpoints that allow clients to
    manage agents.
    """

    @staticmethod
    def Liveness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/Liveness',
            agent_dot_agent_dot_v1alpha_dot_agent__pb2.LivenessRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_agent__pb2.LivenessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Readiness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/Readiness',
            agent_dot_agent_dot_v1alpha_dot_agent__pb2.ReadinessRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_agent__pb2.ReadinessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateChat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/CreateChat',
            agent_dot_agent_dot_v1alpha_dot_chat__pb2.CreateChatRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_chat__pb2.CreateChatResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListChats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/ListChats',
            agent_dot_agent_dot_v1alpha_dot_chat__pb2.ListChatsRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_chat__pb2.ListChatsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateChat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/UpdateChat',
            agent_dot_agent_dot_v1alpha_dot_chat__pb2.UpdateChatRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_chat__pb2.UpdateChatResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetChat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/GetChat',
            agent_dot_agent_dot_v1alpha_dot_chat__pb2.GetChatRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_chat__pb2.GetChatResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteChat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/DeleteChat',
            agent_dot_agent_dot_v1alpha_dot_chat__pb2.DeleteChatRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_chat__pb2.DeleteChatResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListMessages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/ListMessages',
            agent_dot_agent_dot_v1alpha_dot_chat__pb2.ListMessagesRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_chat__pb2.ListMessagesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChatWithAgent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/agent.agent.v1alpha.AgentPublicService/ChatWithAgent',
            agent_dot_agent_dot_v1alpha_dot_chat__pb2.ChatWithAgentRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_chat__pb2.ChatWithAgentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BindChatTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/BindChatTable',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.BindChatTableRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.BindChatTableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnbindChatTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/UnbindChatTable',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.UnbindChatTableRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.UnbindChatTableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListChatTables(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/ListChatTables',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.ListChatTablesRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.ListChatTablesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListTables(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/ListTables',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.ListTablesRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.ListTablesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/CreateTable',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.CreateTableRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.CreateTableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/GetTable',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.GetTableRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.GetTableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/UpdateTable',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateTableRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateTableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/DeleteTable',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.DeleteTableRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.DeleteTableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChatWithTableBuilderAgent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/agent.agent.v1alpha.AgentPublicService/ChatWithTableBuilderAgent',
            agent_dot_agent_dot_v1alpha_dot_chat__pb2.ChatWithTableBuilderAgentRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_chat__pb2.ChatWithTableBuilderAgentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListTableBuilderAgentMessages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/ListTableBuilderAgentMessages',
            agent_dot_agent_dot_v1alpha_dot_chat__pb2.ListTableBuilderAgentMessagesRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_chat__pb2.ListTableBuilderAgentMessagesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetColumnDefinitions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/GetColumnDefinitions',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.GetColumnDefinitionsRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.GetColumnDefinitionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateColumnDefinitions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/UpdateColumnDefinitions',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateColumnDefinitionsRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateColumnDefinitionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetColumnDefinition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/GetColumnDefinition',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.GetColumnDefinitionRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.GetColumnDefinitionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RecomputeColumn(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/RecomputeColumn',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.RecomputeColumnRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.RecomputeColumnResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListRows(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/ListRows',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.ListRowsRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.ListRowsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/GetRow',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.GetRowRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.GetRowResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InsertRow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/InsertRow',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.InsertRowRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.InsertRowResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateRow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/UpdateRow',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateRowRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateRowResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateRows(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/UpdateRows',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateRowsRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateRowsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteRow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/DeleteRow',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.DeleteRowRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.DeleteRowResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteRows(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/DeleteRows',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.DeleteRowsRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.DeleteRowsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MoveRows(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/MoveRows',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.MoveRowsRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.MoveRowsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCell(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/GetCell',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.GetCellRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.GetCellResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateCell(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/UpdateCell',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateCellRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.UpdateCellResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResetCell(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/ResetCell',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.ResetCellRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.ResetCellResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RecomputeCell(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/RecomputeCell',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.RecomputeCellRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.RecomputeCellResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LockCell(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/LockCell',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.LockCellRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.LockCellResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnlockCell(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/UnlockCell',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.UnlockCellRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.UnlockCellResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTableEvents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/agent.agent.v1alpha.AgentPublicService/GetTableEvents',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.GetTableEventsRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.GetTableEventsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExportTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/agent.agent.v1alpha.AgentPublicService/ExportTable',
            agent_dot_agent_dot_v1alpha_dot_table__pb2.ExportTableRequest.SerializeToString,
            agent_dot_agent_dot_v1alpha_dot_table__pb2.ExportTableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pipeline/pipeline/v1beta/secret.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%pipeline/pipeline/v1beta/secret.proto\x12\x18pipeline.pipeline.v1beta\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\"\x81\x03\n\x06Secret\x12\x17\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x04name\x12\x15\n\x03uid\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x03uid\x12\x13\n\x02id\x18\x03 \x01(\tB\x03\xe0\x41\x05R\x02id\x12@\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12@\n\x0bupdate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTime\x12\x1e\n\x05value\x18\x06 \x01(\tB\x03\xe0\x41\x04H\x00R\x05value\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x07 \x01(\tB\x03\xe0\x41\x01R\x0b\x64\x65scription:]\xea\x41Z\x12#users/{user.id}/secrets/{secret.id}\x12\x33organizations/{organization.id}/secrets/{secret.id}B\x08\n\x06_value\"\x80\x01\n\x1c\x43reateNamespaceSecretRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x38\n\x06secret\x18\x02 \x01(\x0b\x32 .pipeline.pipeline.v1beta.SecretR\x06secret\"^\n\x1d\x43reateNamespaceSecretResponse\x12=\n\x06secret\x18\x01 \x01(\x0b\x32 .pipeline.pipeline.v1beta.SecretB\x03\xe0\x41\x03R\x06secret\"\xb2\x01\n\x1bListNamespaceSecretsRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12%\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_token\"\xb0\x01\n\x1cListNamespaceSecretsResponse\x12?\n\x07secrets\x18\x01 \x03(\x0b\x32 .pipeline.pipeline.v1beta.SecretB\x03\xe0\x41\x03R\x07secrets\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\"e\n\x19GetNamespaceSecretRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\tsecret_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08secretId\"V\n\x1aGetNamespaceSecretResponse\x12\x38\n\x06secret\x18\x01 \x01(\x0b\x32 .pipeline.pipeline.v1beta.SecretR\x06secret\"\xe4\x01\n\x1cUpdateNamespaceSecretRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\tsecret_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08secretId\x12\x38\n\x06secret\x18\x03 \x01(\x0b\x32 .pipeline.pipeline.v1beta.SecretR\x06secret\x12@\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\"Y\n\x1dUpdateNamespaceSecretResponse\x12\x38\n\x06secret\x18\x01 \x01(\x0b\x32 .pipeline.pipeline.v1beta.SecretR\x06secret\"h\n\x1c\x44\x65leteNamespaceSecretRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\tsecret_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08secretId\"\x1f\n\x1d\x44\x65leteNamespaceSecretResponse\"\x82\x01\n\x17\x43reateUserSecretRequest\x12\x38\n\x06secret\x18\x01 \x01(\x0b\x32 .pipeline.pipeline.v1beta.SecretR\x06secret\x12-\n\x06parent\x18\x02 \x01(\tB\x15\x92\x41\x0f\xca>\x0c\xfa\x02\tuser_name\xe0\x41\x02R\x06parent\"T\n\x18\x43reateUserSecretResponse\x12\x38\n\x06secret\x18\x01 \x01(\x0b\x32 .pipeline.pipeline.v1beta.SecretR\x06secret\"\xb4\x01\n\x16ListUserSecretsRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x02 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12-\n\x06parent\x18\x03 \x01(\tB\x15\x92\x41\x0f\xca>\x0c\xfa\x02\tuser_name\xe0\x41\x02R\x06parentB\x0c\n\n_page_sizeB\r\n\x0b_page_token\"\x9c\x01\n\x17ListUserSecretsResponse\x12:\n\x07secrets\x18\x01 \x03(\x0b\x32 .pipeline.pipeline.v1beta.SecretR\x07secrets\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"H\n\x14GetUserSecretRequest\x12\x30\n\x04name\x18\x01 \x01(\tB\x1c\x92\x41\x16\xca>\x13\xfa\x02\x10user_secret_name\xe0\x41\x02R\x04name\"Q\n\x15GetUserSecretResponse\x12\x38\n\x06secret\x18\x01 \x01(\x0b\x32 .pipeline.pipeline.v1beta.SecretR\x06secret\"\x9a\x01\n\x17UpdateUserSecretRequest\x12=\n\x06secret\x18\x01 \x01(\x0b\x32 .pipeline.pipeline.v1beta.SecretB\x03\xe0\x41\x02R\x06secret\x12@\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\"T\n\x18UpdateUserSecretResponse\x12\x38\n\x06secret\x18\x01 \x01(\x0b\x32 .pipeline.pipeline.v1beta.SecretR\x06secret\"K\n\x17\x44\x65leteUserSecretRequest\x12\x30\n\x04name\x18\x01 \x01(\tB\x1c\x92\x41\x16\xca>\x13\xfa\x02\x10user_secret_name\xe0\x41\x02R\x04name\"\x1a\n\x18\x44\x65leteUserSecretResponse\"\x92\x01\n\x1f\x43reateOrganizationSecretRequest\x12\x38\n\x06secret\x18\x01 \x01(\x0b\x32 .pipeline.pipeline.v1beta.SecretR\x06secret\x12\x35\n\x06parent\x18\x02 \x01(\tB\x1d\x92\x41\x17\xca>\x14\xfa\x02\x11organization_name\xe0\x41\x02R\x06parent\"\\\n CreateOrganizationSecretResponse\x12\x38\n\x06secret\x18\x01 \x01(\x0b\x32 .pipeline.pipeline.v1beta.SecretR\x06secret\"\xc4\x01\n\x1eListOrganizationSecretsRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x02 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12\x35\n\x06parent\x18\x03 \x01(\tB\x1d\x92\x41\x17\xca>\x14\xfa\x02\x11organization_name\xe0\x41\x02R\x06parentB\x0c\n\n_page_sizeB\r\n\x0b_page_token\"\xa4\x01\n\x1fListOrganizationSecretsResponse\x12:\n\x07secrets\x18\x01 \x03(\x0b\x32 .pipeline.pipeline.v1beta.SecretR\x07secrets\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"X\n\x1cGetOrganizationSecretRequest\x12\x38\n\x04name\x18\x01 \x01(\tB$\x92\x41\x1e\xca>\x1b\xfa\x02\x18organization_secret_name\xe0\x41\x02R\x04name\"Y\n\x1dGetOrganizationSecretResponse\x12\x38\n\x06secret\x18\x01 \x01(\x0b\x32 .pipeline.pipeline.v1beta.SecretR\x06secret\"\xa2\x01\n\x1fUpdateOrganizationSecretRequest\x12=\n\x06secret\x18\x01 \x01(\x0b\x32 .pipeline.pipeline.v1beta.SecretB\x03\xe0\x41\x02R\x06secret\x12@\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\"\\\n UpdateOrganizationSecretResponse\x12\x38\n\x06secret\x18\x01 \x01(\x0b\x32 .pipeline.pipeline.v1beta.SecretR\x06secret\"[\n\x1f\x44\x65leteOrganizationSecretRequest\x12\x38\n\x04name\x18\x01 \x01(\tB$\x92\x41\x1e\xca>\x1b\xfa\x02\x18organization_secret_name\xe0\x41\x02R\x04name\"\"\n DeleteOrganizationSecretResponseB\xf8\x01\n\x1c\x63om.pipeline.pipeline.v1betaB\x0bSecretProtoP\x01ZIgithub.com/instill-ai/protogen-go/pipeline/pipeline/v1beta;pipelinev1beta\xa2\x02\x03PPX\xaa\x02\x18Pipeline.Pipeline.V1beta\xca\x02\x18Pipeline\\Pipeline\\V1beta\xe2\x02$Pipeline\\Pipeline\\V1beta\\GPBMetadata\xea\x02\x1aPipeline::Pipeline::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pipeline.pipeline.v1beta.secret_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.pipeline.pipeline.v1betaB\013SecretProtoP\001ZIgithub.com/instill-ai/protogen-go/pipeline/pipeline/v1beta;pipelinev1beta\242\002\003PPX\252\002\030Pipeline.Pipeline.V1beta\312\002\030Pipeline\\Pipeline\\V1beta\342\002$Pipeline\\Pipeline\\V1beta\\GPBMetadata\352\002\032Pipeline::Pipeline::V1beta'
  _SECRET.fields_by_name['name']._options = None
  _SECRET.fields_by_name['name']._serialized_options = b'\340A\003'
  _SECRET.fields_by_name['uid']._options = None
  _SECRET.fields_by_name['uid']._serialized_options = b'\340A\003'
  _SECRET.fields_by_name['id']._options = None
  _SECRET.fields_by_name['id']._serialized_options = b'\340A\005'
  _SECRET.fields_by_name['create_time']._options = None
  _SECRET.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _SECRET.fields_by_name['update_time']._options = None
  _SECRET.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _SECRET.fields_by_name['value']._options = None
  _SECRET.fields_by_name['value']._serialized_options = b'\340A\004'
  _SECRET.fields_by_name['description']._options = None
  _SECRET.fields_by_name['description']._serialized_options = b'\340A\001'
  _SECRET._options = None
  _SECRET._serialized_options = b'\352AZ\022#users/{user.id}/secrets/{secret.id}\0223organizations/{organization.id}/secrets/{secret.id}'
  _CREATENAMESPACESECRETREQUEST.fields_by_name['namespace_id']._options = None
  _CREATENAMESPACESECRETREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _CREATENAMESPACESECRETRESPONSE.fields_by_name['secret']._options = None
  _CREATENAMESPACESECRETRESPONSE.fields_by_name['secret']._serialized_options = b'\340A\003'
  _LISTNAMESPACESECRETSREQUEST.fields_by_name['namespace_id']._options = None
  _LISTNAMESPACESECRETSREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LISTNAMESPACESECRETSREQUEST.fields_by_name['page_size']._options = None
  _LISTNAMESPACESECRETSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTNAMESPACESECRETSREQUEST.fields_by_name['page_token']._options = None
  _LISTNAMESPACESECRETSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTNAMESPACESECRETSRESPONSE.fields_by_name['secrets']._options = None
  _LISTNAMESPACESECRETSRESPONSE.fields_by_name['secrets']._serialized_options = b'\340A\003'
  _LISTNAMESPACESECRETSRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTNAMESPACESECRETSRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTNAMESPACESECRETSRESPONSE.fields_by_name['total_size']._options = None
  _LISTNAMESPACESECRETSRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _GETNAMESPACESECRETREQUEST.fields_by_name['namespace_id']._options = None
  _GETNAMESPACESECRETREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _GETNAMESPACESECRETREQUEST.fields_by_name['secret_id']._options = None
  _GETNAMESPACESECRETREQUEST.fields_by_name['secret_id']._serialized_options = b'\340A\002'
  _UPDATENAMESPACESECRETREQUEST.fields_by_name['namespace_id']._options = None
  _UPDATENAMESPACESECRETREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _UPDATENAMESPACESECRETREQUEST.fields_by_name['secret_id']._options = None
  _UPDATENAMESPACESECRETREQUEST.fields_by_name['secret_id']._serialized_options = b'\340A\002'
  _UPDATENAMESPACESECRETREQUEST.fields_by_name['update_mask']._options = None
  _UPDATENAMESPACESECRETREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _DELETENAMESPACESECRETREQUEST.fields_by_name['namespace_id']._options = None
  _DELETENAMESPACESECRETREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _DELETENAMESPACESECRETREQUEST.fields_by_name['secret_id']._options = None
  _DELETENAMESPACESECRETREQUEST.fields_by_name['secret_id']._serialized_options = b'\340A\002'
  _CREATEUSERSECRETREQUEST.fields_by_name['parent']._options = None
  _CREATEUSERSECRETREQUEST.fields_by_name['parent']._serialized_options = b'\222A\017\312>\014\372\002\tuser_name\340A\002'
  _LISTUSERSECRETSREQUEST.fields_by_name['page_size']._options = None
  _LISTUSERSECRETSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTUSERSECRETSREQUEST.fields_by_name['page_token']._options = None
  _LISTUSERSECRETSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTUSERSECRETSREQUEST.fields_by_name['parent']._options = None
  _LISTUSERSECRETSREQUEST.fields_by_name['parent']._serialized_options = b'\222A\017\312>\014\372\002\tuser_name\340A\002'
  _GETUSERSECRETREQUEST.fields_by_name['name']._options = None
  _GETUSERSECRETREQUEST.fields_by_name['name']._serialized_options = b'\222A\026\312>\023\372\002\020user_secret_name\340A\002'
  _UPDATEUSERSECRETREQUEST.fields_by_name['secret']._options = None
  _UPDATEUSERSECRETREQUEST.fields_by_name['secret']._serialized_options = b'\340A\002'
  _UPDATEUSERSECRETREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEUSERSECRETREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _DELETEUSERSECRETREQUEST.fields_by_name['name']._options = None
  _DELETEUSERSECRETREQUEST.fields_by_name['name']._serialized_options = b'\222A\026\312>\023\372\002\020user_secret_name\340A\002'
  _CREATEORGANIZATIONSECRETREQUEST.fields_by_name['parent']._options = None
  _CREATEORGANIZATIONSECRETREQUEST.fields_by_name['parent']._serialized_options = b'\222A\027\312>\024\372\002\021organization_name\340A\002'
  _LISTORGANIZATIONSECRETSREQUEST.fields_by_name['page_size']._options = None
  _LISTORGANIZATIONSECRETSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTORGANIZATIONSECRETSREQUEST.fields_by_name['page_token']._options = None
  _LISTORGANIZATIONSECRETSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTORGANIZATIONSECRETSREQUEST.fields_by_name['parent']._options = None
  _LISTORGANIZATIONSECRETSREQUEST.fields_by_name['parent']._serialized_options = b'\222A\027\312>\024\372\002\021organization_name\340A\002'
  _GETORGANIZATIONSECRETREQUEST.fields_by_name['name']._options = None
  _GETORGANIZATIONSECRETREQUEST.fields_by_name['name']._serialized_options = b'\222A\036\312>\033\372\002\030organization_secret_name\340A\002'
  _UPDATEORGANIZATIONSECRETREQUEST.fields_by_name['secret']._options = None
  _UPDATEORGANIZATIONSECRETREQUEST.fields_by_name['secret']._serialized_options = b'\340A\002'
  _UPDATEORGANIZATIONSECRETREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEORGANIZATIONSECRETREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _DELETEORGANIZATIONSECRETREQUEST.fields_by_name['name']._options = None
  _DELETEORGANIZATIONSECRETREQUEST.fields_by_name['name']._serialized_options = b'\222A\036\312>\033\372\002\030organization_secret_name\340A\002'
  _globals['_SECRET']._serialized_start=243
  _globals['_SECRET']._serialized_end=628
  _globals['_CREATENAMESPACESECRETREQUEST']._serialized_start=631
  _globals['_CREATENAMESPACESECRETREQUEST']._serialized_end=759
  _globals['_CREATENAMESPACESECRETRESPONSE']._serialized_start=761
  _globals['_CREATENAMESPACESECRETRESPONSE']._serialized_end=855
  _globals['_LISTNAMESPACESECRETSREQUEST']._serialized_start=858
  _globals['_LISTNAMESPACESECRETSREQUEST']._serialized_end=1036
  _globals['_LISTNAMESPACESECRETSRESPONSE']._serialized_start=1039
  _globals['_LISTNAMESPACESECRETSRESPONSE']._serialized_end=1215
  _globals['_GETNAMESPACESECRETREQUEST']._serialized_start=1217
  _globals['_GETNAMESPACESECRETREQUEST']._serialized_end=1318
  _globals['_GETNAMESPACESECRETRESPONSE']._serialized_start=1320
  _globals['_GETNAMESPACESECRETRESPONSE']._serialized_end=1406
  _globals['_UPDATENAMESPACESECRETREQUEST']._serialized_start=1409
  _globals['_UPDATENAMESPACESECRETREQUEST']._serialized_end=1637
  _globals['_UPDATENAMESPACESECRETRESPONSE']._serialized_start=1639
  _globals['_UPDATENAMESPACESECRETRESPONSE']._serialized_end=1728
  _globals['_DELETENAMESPACESECRETREQUEST']._serialized_start=1730
  _globals['_DELETENAMESPACESECRETREQUEST']._serialized_end=1834
  _globals['_DELETENAMESPACESECRETRESPONSE']._serialized_start=1836
  _globals['_DELETENAMESPACESECRETRESPONSE']._serialized_end=1867
  _globals['_CREATEUSERSECRETREQUEST']._serialized_start=1870
  _globals['_CREATEUSERSECRETREQUEST']._serialized_end=2000
  _globals['_CREATEUSERSECRETRESPONSE']._serialized_start=2002
  _globals['_CREATEUSERSECRETRESPONSE']._serialized_end=2086
  _globals['_LISTUSERSECRETSREQUEST']._serialized_start=2089
  _globals['_LISTUSERSECRETSREQUEST']._serialized_end=2269
  _globals['_LISTUSERSECRETSRESPONSE']._serialized_start=2272
  _globals['_LISTUSERSECRETSRESPONSE']._serialized_end=2428
  _globals['_GETUSERSECRETREQUEST']._serialized_start=2430
  _globals['_GETUSERSECRETREQUEST']._serialized_end=2502
  _globals['_GETUSERSECRETRESPONSE']._serialized_start=2504
  _globals['_GETUSERSECRETRESPONSE']._serialized_end=2585
  _globals['_UPDATEUSERSECRETREQUEST']._serialized_start=2588
  _globals['_UPDATEUSERSECRETREQUEST']._serialized_end=2742
  _globals['_UPDATEUSERSECRETRESPONSE']._serialized_start=2744
  _globals['_UPDATEUSERSECRETRESPONSE']._serialized_end=2828
  _globals['_DELETEUSERSECRETREQUEST']._serialized_start=2830
  _globals['_DELETEUSERSECRETREQUEST']._serialized_end=2905
  _globals['_DELETEUSERSECRETRESPONSE']._serialized_start=2907
  _globals['_DELETEUSERSECRETRESPONSE']._serialized_end=2933
  _globals['_CREATEORGANIZATIONSECRETREQUEST']._serialized_start=2936
  _globals['_CREATEORGANIZATIONSECRETREQUEST']._serialized_end=3082
  _globals['_CREATEORGANIZATIONSECRETRESPONSE']._serialized_start=3084
  _globals['_CREATEORGANIZATIONSECRETRESPONSE']._serialized_end=3176
  _globals['_LISTORGANIZATIONSECRETSREQUEST']._serialized_start=3179
  _globals['_LISTORGANIZATIONSECRETSREQUEST']._serialized_end=3375
  _globals['_LISTORGANIZATIONSECRETSRESPONSE']._serialized_start=3378
  _globals['_LISTORGANIZATIONSECRETSRESPONSE']._serialized_end=3542
  _globals['_GETORGANIZATIONSECRETREQUEST']._serialized_start=3544
  _globals['_GETORGANIZATIONSECRETREQUEST']._serialized_end=3632
  _globals['_GETORGANIZATIONSECRETRESPONSE']._serialized_start=3634
  _globals['_GETORGANIZATIONSECRETRESPONSE']._serialized_end=3723
  _globals['_UPDATEORGANIZATIONSECRETREQUEST']._serialized_start=3726
  _globals['_UPDATEORGANIZATIONSECRETREQUEST']._serialized_end=3888
  _globals['_UPDATEORGANIZATIONSECRETRESPONSE']._serialized_start=3890
  _globals['_UPDATEORGANIZATIONSECRETRESPONSE']._serialized_end=3982
  _globals['_DELETEORGANIZATIONSECRETREQUEST']._serialized_start=3984
  _globals['_DELETEORGANIZATIONSECRETREQUEST']._serialized_end=4075
  _globals['_DELETEORGANIZATIONSECRETRESPONSE']._serialized_start=4077
  _globals['_DELETEORGANIZATIONSECRETRESPONSE']._serialized_end=4111
# @@protoc_insertion_point(module_scope)



import argparse

# import hashlib
import os
import platform
import shutil
import subprocess
import tempfile
import uuid

import ray
import yaml

import instill
from instill.helpers.const import DEFAULT_DEPENDENCIES
from instill.helpers.errors import ModelConfigException
from instill.utils.logger import Logger

bash_script = """
until curl -s -o /dev/null -w "%{http_code}" http://localhost:8265 | grep -q "200"; do
    sleep 5
done
"""


def config_check_required_fields(c):
    """Check if required fields are present in the model configuration."""
    if "build" not in c or c["build"] is None:
        raise ModelConfigException("build")
    if "gpu" not in c["build"] or c["build"]["gpu"] is None:
        raise ModelConfigException("gpu")
    if "python_version" not in c["build"] or c["build"]["python_version"] is None:
        raise ModelConfigException("python_version")


def cli():
    """Command line interface for the Instill CLI tool."""
    if platform.machine() in ("i386", "AMD64", "x86_64"):
        default_platform = "amd64"
    else:
        default_platform = platform.machine()
    parser = argparse.ArgumentParser()
    subcommands = parser.add_subparsers(required=True)

    # init
    init_parser = subcommands.add_parser("init", help="Initialize model directory")
    init_parser.set_defaults(func=init)

    # build
    build_parser = subcommands.add_parser("build", help="Build model image")
    build_parser.set_defaults(func=build)
    build_parser.add_argument(
        "name",
        help="user and model namespace, in the format of <user-id>/<model-id>[:tag] (default tag is 'latest')",
    )
    build_parser.add_argument(
        "-n",
        "--no-cache",
        help="build the image without cache",
        action="store_true",
        required=False,
    )
    build_parser.add_argument(
        "-a",
        "--target-arch",
        help="target platform architecture for the model image, default to host architecture",
        default=default_platform,
        choices=["arm64", "amd64"],
        required=False,
    )
    build_parser.add_argument(
        "-w",
        "--sdk-wheel",
        help="instill sdk wheel absolute path for debug purpose",
        default=None,
        required=False,
    )
    build_parser.add_argument(
        "-e",
        "--editable-project",
        help="path to local Python project to install in editable mode (overrides --sdk-wheel if both are specified)",
        default=None,
        required=False,
    )

    # push
    push_parser = subcommands.add_parser("push", help="Push model image")
    push_parser.set_defaults(func=push)
    push_parser.add_argument(
        "name",
        help="user and model namespace, in the format of <user-id>/<model-id>[:tag] (default tag is 'latest')",
    )
    push_parser.add_argument(
        "-u",
        "--url",
        help="image registry url, in the format of host:port, default to api.instill.tech",
        default="api.instill.tech",
        required=False,
    )

    # run
    run_parser = subcommands.add_parser("run", help="Run inference on model image")
    run_parser.set_defaults(func=run)
    run_parser.add_argument(
        "name",
        help="user and model namespace, in the format of <user-id>/<model-id>[:tag] (default tag is 'latest')",
    )
    run_parser.add_argument(
        "-g",
        "--gpu",
        help="whether the model needs gpu",
        action="store_true",
        required=False,
    )
    run_parser.add_argument(
        "-ng",
        "--num-of-gpus",
        help="number of gpus to use if gpu flag is on, default to 1",
        type=int,
        default=1,
        required=False,
    )
    run_parser.add_argument(
        "-i",
        "--input",
        help="inference input json",
        required=True,
    )

    args = parser.parse_args()
    args.func(args)


def init(_):
    """Initialize a new model directory with template files."""
    shutil.copyfile(
        __file__.replace("cli.py", "init-templates/instill.yaml"),
        f"{os.getcwd()}/instill.yaml",
    )
    shutil.copyfile(
        __file__.replace("cli.py", "init-templates/model.py"),
        f"{os.getcwd()}/model.py",
    )


def find_project_root(start_path):
    """Find the Python project root by looking for setup.py or pyproject.toml"""
    current_path = os.path.abspath(start_path)
    while current_path != "/":
        if os.path.exists(os.path.join(current_path, "setup.py")) or os.path.exists(
            os.path.join(current_path, "pyproject.toml")
        ):
            return current_path
        current_path = os.path.dirname(current_path)
    return None


def is_vllm_version_compatible(version_parts):
    """Check if vLLM version meets minimum requirements (v0.6.5)"""
    return not (
        version_parts[0] < 0
        or (version_parts[0] == 0 and version_parts[1] < 6)
        or (version_parts[0] == 0 and version_parts[1] == 6 and version_parts[2] < 5)
    )


def prepare_build_environment(build_params):
    """Prepare environment variables and settings for the build process."""
    python_version = build_params["python_version"].replace(".", "")
    ray_version = ray.__version__
    instill_sdk_version = instill.__version__

    # Determine CUDA suffix
    if not build_params["gpu"]:
        cuda_suffix = ""
    elif "cuda_version" in build_params and not build_params["cuda_version"] is None:
        cuda_suffix = f'-cu{build_params["cuda_version"].replace(".", "")}'
    else:
        cuda_suffix = "-gpu"

    # Prepare system packages
    system_pkg_list = []
    if (
        "system_packages" in build_params
        and not build_params["system_packages"] is None
    ):
        system_pkg_list.extend(build_params["system_packages"])
    system_pkg_str = " ".join(system_pkg_list)

    # Prepare Python packages
    python_pkg_list = []
    if (
        "python_packages" in build_params
        and build_params["python_packages"] is not None
    ):
        python_pkg_list.extend(build_params["python_packages"])
    python_pkg_list.extend(DEFAULT_DEPENDENCIES)

    return (
        python_version,
        ray_version,
        instill_sdk_version,
        cuda_suffix,
        system_pkg_str,
        python_pkg_list,
    )


def process_arm64_packages(python_pkg_list, target_arch):
    """Process packages for ARM64 architecture, handling vLLM and other dependencies."""
    dockerfile = "Dockerfile"
    vllm_version = None

    if target_arch == "arm64":
        filtered_pkg_list = []
        for pkg in python_pkg_list:
            if pkg.startswith("vllm"):
                # Transform version string from "0.6.4.post1" to "v0.6.4"
                version = pkg.split("==")[1]
                vllm_version = f"v{version.split('.post')[0]}"
                # Check if version is at least v0.6.5
                base_version = version.split(".post")[0]
                version_parts = [int(x) for x in base_version.split(".")]
                if not is_vllm_version_compatible(version_parts):
                    raise ValueError(
                        f"[Instill] vLLM version must be at least v0.6.5, got {vllm_version}"
                    )
            elif pkg.startswith("bitsandbytes"):
                raise ValueError(
                    "[Instill] bitsandbytes is not supported on ARM architecture"
                )
            else:
                filtered_pkg_list.append(pkg)

        python_pkg_list = filtered_pkg_list
        if vllm_version is not None and target_arch == "arm64":
            dockerfile = "Dockerfile.vllm"

    python_pkg_str = " ".join(python_pkg_list)
    target_arch_suffix = "-aarch64" if target_arch == "arm64" else ""

    return dockerfile, vllm_version, python_pkg_str, target_arch_suffix, python_pkg_list


def parse_image_name(name):
    """Parse image name to extract name and tag."""
    if ":" in name:
        image, tag = name.split(":", 1)
        return image, tag
    return name, "latest"


def prepare_build_command(args, tmpdir, dockerfile, build_vars):
    """Prepare the Docker build command with all necessary arguments."""
    vllm_version, target_arch_suffix, ray_version, python_version = build_vars[:4]
    cuda_suffix, python_pkg_str, system_pkg_str, instill_sdk_version = build_vars[4:8]
    instill_python_sdk_project_name = build_vars[8]

    image_name, tag = parse_image_name(args.name)

    command = [
        "docker",
        "buildx",
        "build",
        "--progress=plain",
        "--file",
        f"{tmpdir}/{dockerfile}",
        "--build-arg",
        f"TARGET_ARCH_SUFFIX={target_arch_suffix}",
        "--build-arg",
        f"RAY_VERSION={ray_version}",
        "--build-arg",
        f"PYTHON_VERSION={python_version}",
        "--build-arg",
        f"PYTHON_PACKAGES={python_pkg_str}",
        "--build-arg",
        f"INSTILL_PYTHON_SDK_VERSION={instill_sdk_version}",
        "--platform",
        f"linux/{args.target_arch}",
        "-t",
        f"{image_name}:{tag}",
        tmpdir,
        "--load",
    ]

    # Add conditional build args
    if args.no_cache:
        command.append("--no-cache")

    if vllm_version:
        command.extend(["--build-arg", f"VLLM_VERSION={vllm_version}"])

    if cuda_suffix:
        command.extend(["--build-arg", f"CUDA_SUFFIX={cuda_suffix}"])

    if system_pkg_str:
        command.extend(["--build-arg", f"SYSTEM_PACKAGES={system_pkg_str}"])

    command.extend(
        [
            # editable mode
            "--build-arg",
            f"INSTILL_PYTHON_SDK_PROJECT_NAME={instill_python_sdk_project_name}",
            "--build-arg",
            (
                "PYTHONPATH_USER_DEFINED_PROTO=/home/ray/"
                f"{instill_python_sdk_project_name}/instill/protogen/model/ray/v1alpha"
            ),
        ]
        if instill_python_sdk_project_name
        else [
            "--build-arg",
            (
                "PYTHONPATH_USER_DEFINED_PROTO=/home/ray/"
                "anaconda3/lib/python3.11/site-packages/instill/protogen/model/ray/v1alpha"
            ),
        ]
    )

    return command


def build(args):
    """Build a Docker image for the model with specified configuration."""
    try:
        Logger.i("[Instill] Loading config file...")
        with open("instill.yaml", "r", encoding="utf8") as f:
            Logger.i("[Instill] Parsing config file...")
            config = yaml.safe_load(f)

        config_check_required_fields(config)
        build_params = config["build"]

        # Prepare build environment
        (
            python_version,
            ray_version,
            instill_sdk_version,
            cuda_suffix,
            system_pkg_str,
            python_pkg_list,
        ) = prepare_build_environment(build_params)

        # Process ARM64-specific packages
        (
            dockerfile,
            vllm_version,
            python_pkg_str,
            target_arch_suffix,
            python_pkg_list,
        ) = process_arm64_packages(python_pkg_list, args.target_arch)

        with tempfile.TemporaryDirectory() as tmpdir:

            # Copy files to tmpdir
            docker_dir = __file__.replace("cli.py", "docker")
            shutil.copyfile(f"{docker_dir}/{dockerfile}", f"{tmpdir}/Dockerfile")
            shutil.copyfile(f"{docker_dir}/.dockerignore", f"{tmpdir}/.dockerignore")
            shutil.copytree(
                os.getcwd(),
                tmpdir,
                ignore=shutil.ignore_patterns("model.py"),
                dirs_exist_ok=True,
            )
            shutil.copyfile(f"{os.getcwd()}/model.py", f"{tmpdir}/_model.py")

            # Handle SDK wheel if provided
            if args.sdk_wheel is not None:
                shutil.copyfile(
                    args.sdk_wheel,
                    f"{tmpdir}/instill_sdk-{instill_sdk_version}dev-py3-none-any.whl",
                )

            # Handle editable project installation
            instill_sdk_project_name = None
            if args.editable_project:
                project_root = find_project_root(args.editable_project)
                if project_root is None:
                    raise FileNotFoundError(
                        "[Instill] No Python project found at the specified path (missing setup.py or pyproject.toml)"
                    )
                instill_sdk_project_name = os.path.basename(project_root)
                Logger.i(f"[Instill] Found Python project: {instill_sdk_project_name}")
                shutil.copytree(
                    project_root,
                    f"{tmpdir}/{instill_sdk_project_name}",
                    dirs_exist_ok=True,
                )

            Logger.i("[Instill] Building model image...")
            build_vars = [
                vllm_version,
                target_arch_suffix,
                ray_version,
                python_version,
                cuda_suffix,
                python_pkg_str,
                system_pkg_str,
                instill_sdk_version,
                instill_sdk_project_name,
            ]
            command = prepare_build_command(args, tmpdir, dockerfile, build_vars)

            subprocess.run(command, check=True)
            image_name, tag = parse_image_name(args.name)
            Logger.i(f"[Instill] {image_name}:{tag} built")
    except subprocess.CalledProcessError:
        Logger.e("[Instill] Build failed")
    except (ValueError, FileNotFoundError, OSError, IOError) as e:
        Logger.e("[Instill] Prepare failed")
        Logger.e(e)
    finally:
        Logger.i("[Instill] Done")


def push(args):
    """Push a built model image to a Docker registry."""
    registry = args.url
    image_name, tag = parse_image_name(args.name)
    tagged_image = f"{registry}/{image_name}:{tag}"
    try:
        # Tag the image
        subprocess.run(
            [
                "docker",
                "tag",
                f"{image_name}:{tag}",
                tagged_image,
            ],
            check=True,
        )
        Logger.i("[Instill] Pushing model image...")
        # Push the image
        subprocess.run(["docker", "push", tagged_image], check=True)
        Logger.i(f"[Instill] {tagged_image} pushed")
    except subprocess.CalledProcessError:
        Logger.e("[Instill] Push failed")
    except (ConnectionError, OSError, IOError) as e:
        Logger.e("[Instill] Prepare failed")
        Logger.e(e)
    finally:
        # Remove the tagged image regardless of success/failure
        try:
            subprocess.run(
                ["docker", "rmi", tagged_image],
                check=True,
            )
        except subprocess.CalledProcessError:
            Logger.e(f"[Instill] Failed to remove tagged image {tagged_image}")
        Logger.i("[Instill] Done")


def run(args):
    """Run inference on a model image."""
    docker_run = False
    try:
        name = uuid.uuid4()
        image_name, tag = parse_image_name(args.name)
        Logger.i("[Instill] Starting model image...")
        if not args.gpu:
            subprocess.run(
                [
                    "docker",
                    "run",
                    "--rm",
                    "-d",
                    "--shm-size=4gb",
                    "--name",
                    str(name),
                    f"{image_name}:{tag}",
                    "serve",
                    "run",
                    "_model:entrypoint",
                ],
                check=True,
                stdout=subprocess.DEVNULL,
            )
        else:
            subprocess.run(
                f"docker run \
                    --rm -d --shm-size=4gb --name {str(name)} --gpus all \
                    {image_name}:{tag} /bin/bash -c \
                        \"serve build _model:entrypoint -o serve.yaml && \
                        sed -i 's/app1/default/' serve.yaml && \
                        sed -i 's/num_cpus: 0.0/num_gpus: {args.num_of_gpus}/' serve.yaml && \
                        serve run serve.yaml\"",
                shell=True,
                check=True,
                stdout=subprocess.DEVNULL,
            )
        docker_run = True
        subprocess.run(
            f"docker exec {str(name)} /bin/bash -c '{bash_script}'",
            shell=True,
            check=True,
            stdout=subprocess.DEVNULL,
            timeout=300,
        )

        Logger.i("[Instill] Deploying model...")
        subprocess.run(
            [
                "docker",
                "exec",
                str(name),
                "/bin/bash",
                "-c",
                "until serve status --name default | grep 'RUNNING: 1' > /dev/null; do sleep 1; done;",
            ],
            check=True,
        )
        Logger.i("[Instill] Running inference...")
        subprocess.run(
            [
                "docker",
                "exec",
                str(name),
                "python",
                "-m",
                "instill.helpers.test",
                "-i",
                args.input,
            ],
            check=True,
        )
    except subprocess.CalledProcessError:
        Logger.e("[Instill] Run failed")
    except subprocess.TimeoutExpired:
        Logger.e("[Instill] Deployment timeout")
    except (RuntimeError, OSError, IOError) as e:
        Logger.e("[Instill] Prepare failed")
        Logger.e(e)
    finally:
        if docker_run:
            subprocess.run(
                [
                    "docker",
                    "stop",
                    str(name),
                ],
                check=True,
                stdout=subprocess.DEVNULL,
            )
        Logger.i("[Instill] Done")


if __name__ == "__main__":
    cli()
